AggTradeMessage

Struct AggTradeMessage 

pub struct AggTradeMessage {
Show 25 fields pub event_type: String, pub event_time: u64, pub symbol: String, pub agg_trade_id: u64, pub price: String, pub quantity: String, pub first_trade_id: u64, pub last_trade_id: u64, pub trade_time: u64, pub is_buyer_maker: bool, pub tx_hash: String, pub user_address: Option<String>, pub order_id: Option<u64>, pub is_maker: Option<bool>, pub is_full_fill: Option<bool>, pub is_liquidation: Option<bool>, pub fee: Option<String>, pub net_fee: Option<String>, pub fee_asset: Option<String>, pub client_order_id: Option<ClientOrderId>, pub side: Option<String>, pub fill_type: Option<String>, pub cumulative_filled_size: Option<String>, pub cumulative_filled_cot: Option<String>, pub remaining_size: Option<String>,
}
AggTrade message with DEX-specific fields.

As of trading-api 2026-05-23, the DEX-specific fields (ua, oi, mk, ff, lq, fe, nf, fa, co, sd, ft, z, Z, rs) are emitted as deprecated empty/zero placeholders. Consumers should treat their values as meaningless and use @user.orders for real fill data.

Fields

event_type: Stringevent_time: u64symbol: Stringagg_trade_id: u64price: Stringquantity: Stringfirst_trade_id: u64last_trade_id: u64trade_time: u64is_buyer_maker: booltx_hash: Stringuser_address: Option<String>

Deprecated: empty-string placeholder as of 2026-05-23. Use @user.orders.

order_id: Option<u64>

Deprecated: zero placeholder as of 2026-05-23. Use @user.orders i field.

is_maker: Option<bool>

Deprecated: empty placeholder as of 2026-05-23. Use @user.orders m field.

is_full_fill: Option<bool>

Deprecated: empty placeholder as of 2026-05-23. Use order status X or rs == 0.

is_liquidation: Option<bool>

Deprecated: empty placeholder as of 2026-05-23. Use @user.orders fill type ft.

fee: Option<String>

Deprecated: zero placeholder as of 2026-05-23. Use @user.orders n.

net_fee: Option<String>

Deprecated: zero placeholder as of 2026-05-23.

fee_asset: Option<String>

Deprecated: empty-string placeholder as of 2026-05-23. Use @user.orders N.

client_order_id: Option<ClientOrderId>

Deprecated: empty placeholder as of 2026-05-23. Use @user.orders co.

side: Option<String>

Deprecated: empty-string placeholder as of 2026-05-23. Use @user.orders S.

fill_type: Option<String>

Deprecated: emitted as zero/empty placeholder. Use @user.orders ft.

cumulative_filled_size: Option<String>

Deprecated: emitted as zero/empty placeholder. Use @user.orders z.

cumulative_filled_cot: Option<String>

Deprecated: emitted as zero/empty placeholder. Use @user.orders Z.

remaining_size: Option<String>

Deprecated: emitted as zero/empty placeholder. Use @user.orders rs.